[java-shib-metadata] branch main updated: Fix javadoc reference error.

Scott Cantor cantor.2 at osu.edu
Tue Mar 25 23:08:10 UTC 2025


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-shib-metadata.

View the commit online:
http://git.shibboleth.net/view/?p=java-shib-metadata.git;a=commit;h=453f32d4e692778ad0f663b88e707c295ad628ae

The following commit(s) were added to refs/heads/main by this push:
     new 453f32d4 Fix javadoc reference error.
453f32d4 is described below

commit 453f32d4e692778ad0f663b88e707c295ad628ae
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Tue Mar 25 19:08:03 2025 -0400

    Fix javadoc reference error.
---
 .../net/shibboleth/spring/metadata/filter/SchemaValidationParser.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/shib-metadata-spring/src/main/java/net/shibboleth/spring/metadata/filter/SchemaValidationParser.java b/shib-metadata-spring/src/main/java/net/shibboleth/spring/metadata/filter/SchemaValidationParser.java
index 01b11252..e5477178 100644
--- a/shib-metadata-spring/src/main/java/net/shibboleth/spring/metadata/filter/SchemaValidationParser.java
+++ b/shib-metadata-spring/src/main/java/net/shibboleth/spring/metadata/filter/SchemaValidationParser.java
@@ -18,6 +18,7 @@ import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 import javax.xml.namespace.QName;
 
+import org.opensaml.saml.common.xml.SAMLSchemaBuilder;
 import org.opensaml.saml.metadata.resolver.filter.impl.SchemaValidationFilter;
 import org.springframework.beans.factory.BeanCreationException;
 import org.springframework.beans.factory.support.BeanDefinitionBuilder;
@@ -25,7 +26,6 @@ import org.springframework.beans.factory.xml.ParserContext;
 import org.w3c.dom.Element;
 
 import net.shibboleth.shared.xml.AttributeSupport;
-import net.shibboleth.shared.xml.SchemaBuilder;
 import net.shibboleth.spring.metadata.AbstractMetadataProviderParser;
 
 /**
@@ -37,7 +37,7 @@ public class SchemaValidationParser extends AbstractMetadataFilterParser {
     @Nonnull public static final QName TYPE_NAME =
             new QName(AbstractMetadataProviderParser.METADATA_NAMESPACE, "SchemaValidation");
 
     /** Bean ID for defaulted {@link SchemaBuilder} instance. */
     @Nullable private final String schemaBuilderRef;
 
     /** Constructor. */
@@ -37,7 +37,7 @@ public class SchemaValidationParser extends AbstractMetadataFilterParser {
             new QName(AbstractMetadataProviderParser.METADATA_NAMESPACE, "SchemaValidation");
 
-    /** Bean ID for defaulted {@link SchemaBuilder} instance. */
+    /** Bean ID for defaulted {@link SAMLSchemaBuilder} instance. */
     @Nullable private final String schemaBuilderRef;
 

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list